aboutsummaryrefslogtreecommitdiff
path: root/layers/core_validation.cpp
diff options
context:
space:
mode:
authorMark Lobodzinski <mark@lunarg.com>2017-01-11 09:34:01 -0700
committerMark Lobodzinski <mark@lunarg.com>2017-01-17 14:58:38 -0700
commit4a4d70b99f38231f495a232da13a82e72850e963 (patch)
tree7eefd208c89b205af99d4b8fba04f9646d8f115f /layers/core_validation.cpp
parent983fe6cff08df7fd632fa3b51d2f4b31f2b3daac (diff)
downloadusermoji-4a4d70b99f38231f495a232da13a82e72850e963.tar.xz
layers: Add physical device props init to CV
Image layer checks need limits/caps. Change-Id: Ib01d194e57563e327ce15846a7a384d78929ebc4
Diffstat (limited to 'layers/core_validation.cpp')
-rw-r--r--layers/core_validation.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/layers/core_validation.cpp b/layers/core_validation.cpp
index 651320d4..ade1ce7d 100644
--- a/layers/core_validation.cpp
+++ b/layers/core_validation.cpp
@@ -174,6 +174,7 @@ struct layer_data {
// Device specific data
PHYS_DEV_PROPERTIES_NODE phys_dev_properties = {};
VkPhysicalDeviceMemoryProperties phys_dev_mem_props = {};
+ VkPhysicalDeviceProperties phys_dev_props = {};
};
// TODO : Do we need to guard access to layer_data_map w/ lock?
@@ -4280,8 +4281,9 @@ VKAPI_ATTR VkResult VKAPI_CALL CreateDevice(VkPhysicalDevice gpu, const VkDevice
} else {
memset(&my_device_data->enabled_features, 0, sizeof(VkPhysicalDeviceFeatures));
}
// Store physical device mem limits into device layer_data struct
my_instance_data->dispatch_table.GetPhysicalDeviceMemoryProperties(gpu, &my_device_data->phys_dev_mem_props);
+ my_instance_data->dispatch_table.GetPhysicalDeviceProperties(gpu, &my_device_data->phys_dev_props);
lock.unlock();
ValidateLayerOrdering(*pCreateInfo);
@@ -4280,8 +4281,9 @@ VKAPI_ATTR VkResult VKAPI_CALL CreateDevice(VkPhysicalDevice gpu, const VkDevice
memset(&my_device_data->enabled_features, 0, sizeof(VkPhysicalDeviceFeatures));
}
- // Store physical device mem limits into device layer_data struct
+ // Store physical device properties and physical device mem limits into device layer_data structs
my_instance_data->dispatch_table.GetPhysicalDeviceMemoryProperties(gpu, &my_device_data->phys_dev_mem_props);